/***********************************************************************/
/*                                                                     */
/*                              Pio (C++)                              */
/*                                                                     */
/*                    Polyglot Input/Output Library                    */
/*                                                                     */
/*               EPI Pomdapi, INRIA Paris - Rocquencourt               */
/*                                                                     */
/*  Copyright 2005-2014 INRIA.                                         */
/*  Institut National de Recherche en Informatique et en Automatique.  */
/*  All rights reserved. This file is distributed only by permission.  */
/*                                                                     */
/*  Estelle Marchand <Estelle.Marchand@inria.fr>                       */
/*                                                                     */
/***********************************************************************/

/* $Id: communication.hpp,v 1.9 2014/01/10 19:22:09 fclement Exp $ */

#include "phrase.hpp"
#include "task.hpp"
#include "result.hpp"
#include "error.hpp"
#include "service.hpp"

#ifndef _COMMUNICATION_H
#define _COMMUNICATION_H

namespace io{

  enum Communication_type{EMPTYcom,PHRASE,TASK,RESULT,ERROR,SERVICE};

  class Communication{
    Communication_type communication_type;
    Elem<Phrase> phrase;
    Elem<Task> task;
    Elem<Result> result;
    Elem<Error> error;
    Elem<Service> service;
  public:
    Communication_type type();
    string printable_type();
    unsigned int size();
    Communication();
    Communication(const Phrase& _phrase);
    Communication(const Task& _task);
    Communication(const Result& _result);
    Communication(const Error& _error);
    Communication(const Service& _service);
    Communication(Communication_type);
    Communication(string s);
    virtual ~Communication();
    Phrase & to_phrase();
    Task & to_task();
    Result & to_result();
    Error & to_error();
    Service & to_service();
    vector<Typed_value>& values();
    void add(Typed_value);
  };
  
}


#endif
